package de.psychometrica.lsa;

/**
 * The class serves as a storage objects for the data of the vector
 * @author Wolfgang Lenhard
 *
 */
public class SemanticVector {
	private float weight = 0;
	private float[] coordinate = new float[300];
	private String word = "";

	private int numberOfWords = 0;

	/**Initialize the vector and set the text
	 * @param word the text of the vector
	 * @param weight the weight of the word
	 * @param coordinate the coordinates of the vector
	 */
	public SemanticVector(String word, float weight, float[] coordinate) {
		super();
		this.coordinate = coordinate;
		this.word = word;
		this.weight = weight;
	}

	/**Initialize the vector and set the text
	 * @param text
	 */
	public SemanticVector(String text) {
		for (int i = 0; i < coordinate.length; i++) {
			coordinate[i] = 0.0f;
		}
		word = text;
	}

	/**
	 * @return the coordinates of this vector
	 */
	public float[] getCoordinate() {
		return coordinate;
	}

	/**
	 * @param coordinate sets the coordinates for the vector
	 */
	public void setCoordinate(float[] coordinate) {
		this.coordinate = coordinate;
	}

	/**
	 * @return the text of the vector
	 */
	public String getWord() {
		return word;
	}

	/**Set the text of the vector
	 * @param word the text to set
	 */
	public void setWord(String word) {
		this.word = word;
	}

	/**Get a specific coordinate
	 * @param dimension the index of the dimension
	 * @return the specific value
	 */
	public float getCoordinate(int dimension) {
		return coordinate[dimension];
	}

	/**Sets the coordinate for a specific dimension of this vector.
	 * @param coordinate the coordinate
	 * @param dimension the index of the dimension
	 */
	public void setCoordinate(float coordinate, int dimension) {
		this.coordinate[dimension] = coordinate;
	}

	/**Set the weight of this word
	 * @param weight the weight to set
	 */
	public void setWeight(float weight) {
		this.weight = weight;
	}

	/**
	 * @return the weight of this vector
	 */
	public float getWeight() {
		return weight;
	}

	/**Set the number of words, this vector is composed of.
	 * @param numberOfWords the number
	 */
	public void setNumberOfWords(int numberOfWords) {
		this.numberOfWords = numberOfWords;
	}

	/**
	 * @return the number of words in the vector
	 */
	public int getNumberOfWords() {
		return numberOfWords;
	}

	/**
	 * Increment the number of words, this vector is composed of
	 */
	public void incrementNumberOfWords() {
		numberOfWords++;
	}

	/**Add a specific coordinate
	 * @param index the index of the dimension
	 * @param data the value to add
	 */
	public void addCoordinate(int index, float data) {
		coordinate[index] += data;
	}

	/**Compute the length of the vector
	 * @return the vector length
	 */
	public float getVectorLength() {
		double length = .0f;
		for (int i = 0; i < getCoordinate().length; i++)
			length += getCoordinate(i) * getCoordinate(i);

		return (float) Math.sqrt(length);
	}
}
